@@ -254,3 +254,107 @@ setClass(".Legend", representation( leg = "logical",        # whether to draw a
 
     invisible()
 }
+
+## Plot a scatter plot of the data 'x' and superimpose a
+##  (cutoff-)tollernce ellipse.
+##  The differences to tolEllipsePlot() in robustbase are:
+##  - customizable (titles, limits, labels, etc)
+##  - can take either a Cov object or a list (aka cov.wt or covMcd)
+##
+.myellipse <- function (x, xcov, 
+    cutoff = NULL, 
+    id.n = NULL, 
+    classic = FALSE, 
+    tol = 1e-07, 
+    xlab = "", 
+    ylab = "", 
+    main="Tolerance ellipse (97.5%)",
+    sub="", 
+    txt.leg=c("robust", "classical"), col.leg = c("red", "blue"), 
+    lty.leg=c("solid", "dashed"),
+    xlim, 
+    ylim) 
+{
+    ellips <- function(loc, cov) {
+        dist <- sqrt(qchisq(0.975, 2))
+        A <- solve(cov)
+        eA <- eigen(A)
+        ev <- eA$values
+        lambda1 <- max(ev)
+        lambda2 <- min(ev)
+        eigvect <- eA$vectors[, order(ev)[2]]
+        z <- seq(0, 2 * pi, by = 0.01)
+        z1 <- dist/sqrt(lambda1) * cos(z)
+        z2 <- dist/sqrt(lambda2) * sin(z)
+        alfa <- atan(eigvect[2]/eigvect[1])
+        r <- matrix(c(cos(alfa), -sin(alfa), sin(alfa), cos(alfa)), 
+            ncol = 2)
+        t(loc + t(cbind(z1, z2) %*% r))
+    }
+    if (is.data.frame(x)) 
+        x <- data.matrix(x)
+    if (!is.matrix(x) || !is.numeric(x)) 
+        stop("x is not a numeric dataframe or matrix.")
+    n <- dim(x)[1]
+    p <- dim(x)[2]
+    if (p != 2) 
+        stop("Dimension {= ncol(x)} must be 2!")
+
+    if(missing(xcov))
+        xcov <- CovMcd(x)
+    if(is(xcov, "Cov"))
+    {
+        x.loc <- getCenter(xcov)
+        x.cov <- getCov(xcov)
+    } else {
+        if (!is.numeric(xcov$center) || !is.numeric(xcov$cov)) 
+            stop("argument 'xcov' must have numeric components 'center' and 'cov'")
+
+        x.loc <- xcov$center
+##        x.cov <- n/(n - 1) * xcov$cov
+        x.cov <- xcov$cov
+    }
+    
+    xM <- colMeans(x)
+    z1 <- ellips(loc = xM, cov = n/(n - 1) * cov.wt(x)$cov)
+    z2 <- ellips(loc = x.loc, cov = x.cov)
+    ## VT::09.06.200
+    ## if no need of the classic ellipse - set it to the robust one
+    ## otherwise the xlim and ylim will be set to fit both ellipses
+
+##    if(classic == FALSE)    
+##        z1 <- z2
+        
+    x1 <- c(min(x[, 1], z1[, 1], z2[, 1]), max(x[, 1], z1[, 1], 
+        z2[, 1]))
+    y1 <- c(min(x[, 2], z1[, 2], z2[, 2]), max(x[, 2], z1[, 2], 
+        z2[, 2]))
+    md <- sqrt(mahalanobis(x, xM, cov(x), tol = tol))
+    rd <- sqrt(mahalanobis(x, x.loc, x.cov, tol = tol))
+    if (missing(cutoff) || is.null(cutoff)) 
+        cutoff <- sqrt(qchisq(0.975, df = 2))
+    if (missing(id.n) || is.null(id.n)) 
+        id.n <- sum(rd > cutoff)
+    ind <- sort(rd, index.return = TRUE)$ix
+    ind <- ind[(n - id.n + 1):n]
+
+    if(missing(xlim))
+        xlim <- x1
+    if(missing(ylim))
+        ylim <- y1
+
+    plot(x, xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, main = main, sub=sub)
+    box()
+    if(id.n > 0) {
+        xrange <- par("usr")
+        xrange <- xrange[2] - xrange[1]
+        text(x[ind, 1] + xrange/50, x[ind, 2], ind)
+    }
+    
+    points(z2, type = "l", lty = lty.leg[1], col = col.leg[1])
+    if (classic) {
+        points(z1, type = "l", lty = lty.leg[2], col = col.leg[2])
+        legend("bottomright", txt.leg, lty = lty.leg, col = col.leg)
+    }
+    invisible()
+}
